==========================
Tandem Pendulum (pendulum)
==========================

This example is a simulation study of a tandem or parallel double pendulum.
The provided regimes not only show the stabilization of the system in different
steady-states. (e.g. both pendulums pointing downwards or both pointing upwards)
but also ways to transition them between those states. (e.g. swinging them up)

Besides a rigid body model, this example features a pout mass model and also
a partially linearized version.

.. image:: pendulum.*